import { createSlice, PayloadAction } from '@reduxjs/toolkit';
import type { RootState } from './store';

/** Extra properties that are not present in the default PaletteOptions of mui. */
export interface ExtraColorsForMui5 {
  /** Colors that can be used for data visualisation, e.g. nodes, edges */
  dataPointColors: string[];
}

/** Our custom color palette config. */
export interface ColorPaletteConfig extends ExtraColorsForMui5 {
  primary: {
    main: string;
  };
}

// This looks very much like the mui Palette interface,
// But we don't reference that type directly here to stay decoupled
export const initialState: ColorPaletteConfig = {
  dataPointColors: ['#ff0000', '#00ff00', '#0000ff'],
  primary: {
    main: '#9999ff',
  },
};

export const colorPaletteConfigSlice = createSlice({
  name: 'colorPaletteConfig',
  // `createSlice` will infer the state type from the `initialState` argument
  initialState,
  reducers: {
    changePrimary: (state, action: PayloadAction<{ main: string }>) => {
      state.primary = action.payload;
    },
    changeDataPointColors: (state, action: PayloadAction<string[]>) => {
      state.dataPointColors = action.payload;
    },
  },
});

export const { changePrimary, changeDataPointColors } =
  colorPaletteConfigSlice.actions;

// Select the schema and convert it to a graphology object
export const selectColorPaletteConfig = (state: RootState) =>
  state.colorPaletteConfig;

export default colorPaletteConfigSlice.reducer;
